import { defineStore } from "pinia";
import { http } from "@/serverCom";
import type { AxiosResponse } from "axios";

export const useDatabaseStore = defineStore("database", {
  state: () => {
    return {
      data: {} as any,
      status: "idle" as "idle" | "working" | "success" | "failed",
      failureReason: '' as string,
      ex: {} as Error,
    };
  },
  actions: {
    async import(noEncryption: boolean, secret: string, requestData: any) {
      try {
        this.data = {};
        this.status = "working";
        this.failureReason = '';
        this.ex = {};
        const requestHeaders = {headers: {'Content-Type': 'application/json', 'x-decrypt-no' : noEncryption}};
        if (!noEncryption) {
          requestHeaders.headers['x-decrypt-with'] = secret;
        }
        await http.post("/admin/database", requestData, requestHeaders);
        this.status = "success";
      } catch (ex) {
        this.status = "failed";
        this.failureReason = (ex as Error).message;
        this.ex = (ex as Error);
        throw ex;
      }
    },
    async export(noEncryption: boolean, secret: string) {
      try {
        this.data = {};
        this.status = "working";
        this.failureReason = '';
        this.ex = {};
        const requestHeaders = {headers: {'Content-Type': 'application/json', 'x-encrypt-no' : noEncryption}};
        if (!noEncryption) {
          requestHeaders.headers['x-encrypt-with'] = secret;
        }
        const response: AxiosResponse = await http.get("/admin/database", requestHeaders);
        this.data = response.data;
        this.status = "success";
      } catch (ex) {
        this.status = "failed";
        this.failureReason = (ex as Error).message;
        this.ex = (ex as Error);
        throw ex;
      }
    },
  },
});
